==> linkall-0.0.1.tgz: package/lib/index.js <==
(function() {
  var betterSpawn, concat, findPackages, path, whichpm;

  betterSpawn = require("better-spawn");

  findPackages = require("find-packages");

  path = require("path");

  whichpm = require("which-pm");

  concat = function(arr1, arr2) {
    return Array.prototype.push.apply(arr1, arr2);
  };

  module.exports = function(options) {
    var children, lookupByName, lookupByPm, peerDeps, pkglist, spawn, spawnOpts, toInstall, toLink;
    children = [];
    spawnOpts = {
      stdio: options.silent ? "pipe" : "inherit"
    };
    spawn = (cmd, wd) => {
      return new Promise((resolve, reject) => {
        var child;
        child = betterSpawn(cmd, Object.assign({
          cwd: wd
        }, spawnOpts));
        children.push(child);
        return child.on("exit", function(exitCode) {
          if (exitCode) {
            return reject(exitCode);
          } else {
            return resolve();
          }
        });
      });
    };
    lookupByName = {};
    lookupByPm = {
      "not installed": []
    };
    pkglist = [];
    toLink = {};
    toLink[options.pm] = [];
    toInstall = [];
    peerDeps = {};
    if (options.verbose) {
      console.log("linkall: searching packages");
    }
    Promise.all(options.cwds.map((cwd) => {
      return findPackages(path.resolve(cwd));
    })).then((results) => {
      var dir, i, j, k, len, len1, len2, pkg, processPkg, ref, res, workers;
      if (options.verbose) {
        console.log("linkall: finished searching for packages");
      }
      workers = [];
      processPkg = (pkg, onlyLookup = false) => {
        lookupByName[pkg.manifest.name] = pkg;
        if (!onlyLookup) {
          pkglist.push(pkg);
        }
        return whichpm(pkg.path).then(function(pm) {
          var arr;
          if (pm != null) {
            pkg.pm = pm = pm.name;
          } else {
            pm = "not installed";
          }
          arr = lookupByPm[pm] != null ? lookupByPm[pm] : lookupByPm[pm] = [];
          return arr.push(pkg);
        });
      };
      ref = options.lds;
      for (i = 0, len = ref.length; i < len; i++) {
        dir = ref[i];
        workers.push(findPackages(path.resolve(dir)).then(function(result) {
          var j, len1, pkg, workers2;
          workers2 = [];
          for (j = 0, len1 = result.length; j < len1; j++) {
            pkg = result[j];
            workers2.push(processPkg(pkg, true));
          }
          return Promise.all(workers2);
        }));
      }
      for (j = 0, len1 = results.length; j < len1; j++) {
        res = results[j];
        for (k = 0, len2 = res.length; k < len2; k++) {
          pkg = res[k];
          workers.push(processPkg(pkg));
        }
      }
      return Promise.all(workers);
    }).then(() => {
      var names, pkgs, pm;
      if (options.verbose) {
        names = [];
        console.log("-----\nlinkall: found following local packages:\n");
        for (pm in lookupByPm) {
          pkgs = lookupByPm[pm];
          console.log(pm + ": " + pkgs.map((pkg) => {
            return pkg.manifest.name;
          }).join(", ") + "\n");
        }
        return console.log("-----");
      }
    }).then(() => {
      var anyFound, i, len, linkup, manifest, pkg, pm, processDep, tmp;
      processDep = function(obj, warn = false) {
        var addDep, dep, i, len, linkup, version;
        linkup = [];
        if (!obj) {
          return linkup;
        }
        addDep = function(name) {
          var arr, n, pd, pkg, pm, results1, v;
          if ((pkg = lookupByName[name])) {
            if ((pm = pkg.pm) == null) {
              if (toInstall.indexOf(pkg) < 0) {
                toInstall.push(pkg);
              }
              pm = options.pm;
            } else if (toLink[pm] == null) {
              toLink[pm] = [];
            }
            if ((arr = toLink[pm]).indexOf(pkg) < 0) {
              arr.push(pkg);
            }
            if (linkup.indexOf(name) < 0) {
              linkup.push(name);
            }
            if ((pd = pkg.manifest.peerDependencies) != null) {
              results1 = [];
              for (n in pd) {
                v = pd[n];
                if (linkup.indexOf(n) < 0) {
                  results1.push(addDep(n));
                } else {
                  results1.push(void 0);
                }
              }
              return results1;
            }
          } else if (warn) {
            return console.log(`linkall: ${name} specified as dep, but not found in local packages`);
          }
        };
        if (Array.isArray(obj)) {
          for (i = 0, len = obj.length; i < len; i++) {
            dep = obj[i];
            addDep(dep);
          }
        } else {
          for (dep in obj) {
            version = obj[dep];
            addDep(dep);
          }
        }
        return linkup;
      };
      console.log("-----\nlinkall: local dependencies found:\n");
      anyFound = false;
      for (i = 0, len = pkglist.length; i < len; i++) {
        pkg = pkglist[i];
        manifest = pkg.manifest;
        if (tmp = manifest.linkall) {
          if (Array.isArray(tmp)) {
            linkup = processDep(tmp, true);
          } else {
            linkup = [];
            if (tmp.dep) {
              concat(linkup, processDep(manifest.dependencies));
            }
            if (tmp.dev) {
              concat(linkup, processDep(manifest.devDependencies));
            }
          }
        } else {
          linkup = processDep(manifest.dependencies);
          concat(linkup, processDep(manifest.devDependencies));
        }
        if (linkup.length > 0) {
          pkg.linkup = linkup;
          if ((pm = pkg.pm) == null) {
            if (toInstall.indexOf(pkg) < 0) {
              toInstall.push(pkg);
            }
          }
          anyFound = true;
          console.log(manifest.name + ":\t" + linkup.join(", "));
        }
      }
      if (!anyFound) {
        console.log("none, exiting ...");
        process.exit();
      }
      return console.log("-----");
    }).then(() => {
      var pkgs, pm;
      if (options.verbose) {
        console.log("-----\nlinkall: need to link up the following packages:\n");
        for (pm in toLink) {
          pkgs = toLink[pm];
          console.log(pm + ": " + pkgs.map((pkg) => {
            return pkg.manifest.name;
          }).join(", ") + "\n");
        }
        console.log("-----");
        if (toInstall.length > 0) {
          console.log(`-----\nlinkall: need to install these packages (using ${options.pm}):\n`);
          return console.log(toInstall.map((pkg) => {
            return pkg.manifest.name;
          }).join(", ") + "\n-----");
        } else {
          return console.log("linkall: no need to install any packages");
        }
      }
    }).then(async function() {
      var i, j, len, len1, pkg, pkgs, pm, ref, results1;
      if (!options.test) {
        for (pm in toLink) {
          pkgs = toLink[pm];
          for (i = 0, len = pkgs.length; i < len; i++) {
            pkg = pkgs[i];
            console.log(`linkall: linking up ${pkg.manifest.name}`);
            try {
              await spawn(pm + " link", pkg.path);
            } catch (error) {
              console.warn(`linkall: linking up ${pkg.manifest.name} failed`);
            }
          }
        }
        results1 = [];
        for (j = 0, len1 = pkglist.length; j < len1; j++) {
          pkg = pkglist[j];
          if (((ref = pkg.linkup) != null ? ref.length : void 0) > 0) {
            pm = pkg.pm || options.pm;
            console.log(`linkall: linking local dependencies for ${pkg.manifest.name}`);
            try {
              results1.push((await spawn(pm + " link " + pkg.linkup.join(" "), pkg.path)));
            } catch (error) {
              results1.push(console.warn(`linkall: linking local dependencies for ${pkg.manifest.name} failed`));
            }
          } else {
            results1.push(void 0);
          }
        }
        return results1;
      }
    }).then(async() => {
      var i, len, pkg, pm, results1;
      if (!options.test && !options.noInstall) {
        pm = options.pm;
        results1 = [];
        for (i = 0, len = toInstall.length; i < len; i++) {
          pkg = toInstall[i];
          console.log(`linkall: installing ${pkg.manifest.name} in ${pkg.path}`);
          try {
            results1.push((await spawn(pm + " install", pkg.path)));
          } catch (error) {
            results1.push(console.warn(`linkall: installing ${pkg.manifest.name} in ${pkg.path} failed`));
          }
        }
        return results1;
      }
    }).catch(function(e) {
      return console.log(e);
    });
    return function(sig) {
      var child, i, len, results1;
      results1 = [];
      for (i = 0, len = children.length; i < len; i++) {
        child = children[i];
        results1.push(child.close(sig));
      }
      return results1;
    };
  };

}).call(this);

==> linkall-0.0.2.tgz: package/lib/index.js <==
(function() {
  var betterSpawn, concat, findPackages, path, whichpm;

  betterSpawn = require("better-spawn");

  findPackages = require("find-packages");

  path = require("path");

  whichpm = require("which-pm");

  concat = (arr1, arr2) => {
    return Array.prototype.push.apply(arr1, arr2);
  };

  module.exports = (options) => {
    var children, lookupByName, lookupByPm, peerDeps, pkglist, spawn, spawnOpts, toInstall, toLink;
    children = [];
    spawnOpts = {
      stdio: options.silent ? "pipe" : "inherit"
    };
    spawn = (cmd, wd) => {
      return new Promise((resolve, reject) => {
        var child;
        child = betterSpawn(cmd, Object.assign({
          cwd: wd
        }, {
          noOut: options.silent
        }));
        children.push(child);
        return child.on("exit", (exitCode) => {
          if (exitCode) {
            return reject(exitCode);
          } else {
            return resolve();
          }
        });
      });
    };
    lookupByName = {};
    lookupByPm = {
      "not installed": []
    };
    pkglist = [];
    toLink = {};
    toLink[options.pm] = [];
    toInstall = [];
    peerDeps = {};
    if (options.verbose) {
      console.log("linkall: searching packages");
    }
    Promise.all(options.cwds.map((cwd) => {
      return findPackages(path.resolve(cwd));
    })).then((results) => {
      var dir, i, j, k, len, len1, len2, pkg, processPkg, ref, res, workers;
      if (options.verbose) {
        console.log("linkall: finished searching for packages");
      }
      workers = [];
      processPkg = (pkg, onlyLookup = false) => {
        lookupByName[pkg.manifest.name] = pkg;
        if (!onlyLookup) {
          pkglist.push(pkg);
        }
        return whichpm(pkg.path).then((pm) => {
          var arr;
          if (pm != null) {
            pkg.pm = pm = pm.name;
          } else {
            pm = "not installed";
          }
          arr = lookupByPm[pm] != null ? lookupByPm[pm] : lookupByPm[pm] = [];
          return arr.push(pkg);
        });
      };
      ref = options.lds;
      for (i = 0, len = ref.length; i < len; i++) {
        dir = ref[i];
        workers.push(findPackages(path.resolve(dir)).then((result) => {
          var j, len1, pkg, workers2;
          workers2 = [];
          for (j = 0, len1 = result.length; j < len1; j++) {
            pkg = result[j];
            workers2.push(processPkg(pkg, true));
          }
          return Promise.all(workers2);
        }));
      }
      for (j = 0, len1 = results.length; j < len1; j++) {
        res = results[j];
        for (k = 0, len2 = res.length; k < len2; k++) {
          pkg = res[k];
          workers.push(processPkg(pkg));
        }
      }
      return Promise.all(workers);
    }).then(() => {
      var names, pkgs, pm;
      if (options.verbose) {
        names = [];
        console.log("-----\nlinkall: found following local packages:\n");
        for (pm in lookupByPm) {
          pkgs = lookupByPm[pm];
          console.log(pm + ": " + pkgs.map((pkg) => {
            return pkg.manifest.name;
          }).join(", ") + "\n");
        }
        return console.log("-----");
      }
    }).then(() => {
      var anyFound, i, len, linkup, manifest, pkg, pm, processDep, tmp;
      processDep = (obj, warn = false) => {
        var addDep, dep, i, len, linkup, version;
        linkup = [];
        if (!obj) {
          return linkup;
        }
        addDep = (name) => {
          var arr, n, pd, pkg, pm, results1, v;
          if ((pkg = lookupByName[name])) {
            if ((pm = pkg.pm) == null) {
              if (toInstall.indexOf(pkg) < 0) {
                toInstall.push(pkg);
              }
              pm = options.pm;
            } else if (toLink[pm] == null) {
              toLink[pm] = [];
            }
            if ((arr = toLink[pm]).indexOf(pkg) < 0) {
              arr.push(pkg);
            }
            if (linkup.indexOf(name) < 0) {
              linkup.push(name);
            }
            if ((pd = pkg.manifest.peerDependencies) != null) {
              results1 = [];
              for (n in pd) {
                v = pd[n];
                if (linkup.indexOf(n) < 0) {
                  results1.push(addDep(n));
                } else {
                  results1.push(void 0);
                }
              }
              return results1;
            }
          } else if (warn) {
            return console.log(`linkall: ${name} specified as dep, but not found in local packages`);
          }
        };
        if (Array.isArray(obj)) {
          for (i = 0, len = obj.length; i < len; i++) {
            dep = obj[i];
            addDep(dep);
          }
        } else {
          for (dep in obj) {
            version = obj[dep];
            addDep(dep);
          }
        }
        return linkup;
      };
      console.log("-----\nlinkall: local dependencies found:\n");
      anyFound = false;
      for (i = 0, len = pkglist.length; i < len; i++) {
        pkg = pkglist[i];
        manifest = pkg.manifest;
        if (tmp = manifest.linkall) {
          if (Array.isArray(tmp)) {
            linkup = processDep(tmp, true);
          } else {
            linkup = [];
            if (tmp.dep) {
              concat(linkup, processDep(manifest.dependencies));
            }
            if (tmp.dev) {
              concat(linkup, processDep(manifest.devDependencies));
            }
          }
        } else {
          linkup = processDep(manifest.dependencies);
          concat(linkup, processDep(manifest.devDependencies));
        }
        if (linkup.length > 0) {
          pkg.linkup = linkup;
          if ((pm = pkg.pm) == null) {
            if (toInstall.indexOf(pkg) < 0) {
              toInstall.push(pkg);
            }
          }
          anyFound = true;
          console.log(manifest.name + ":\t" + linkup.join(", "));
        }
      }
      if (!anyFound) {
        console.log("none, exiting ...");
        process.exit();
      }
      return console.log("-----");
    }).then(() => {
      var pkgs, pm;
      if (options.verbose) {
        console.log("-----\nlinkall: need to link up the following packages:\n");
        for (pm in toLink) {
          pkgs = toLink[pm];
          console.log(pm + ": " + pkgs.map((pkg) => {
            return pkg.manifest.name;
          }).join(", ") + "\n");
        }
        console.log("-----");
        if (toInstall.length > 0) {
          console.log(`-----\nlinkall: need to install these packages (using ${options.pm}):\n`);
          return console.log(toInstall.map((pkg) => {
            return pkg.manifest.name;
          }).join(", ") + "\n-----");
        } else {
          return console.log("linkall: no need to install any packages");
        }
      }
    }).then(async() => {
      var i, j, len, len1, pkg, pkgs, pm, ref, results1;
      if (!options.test) {
        for (pm in toLink) {
          pkgs = toLink[pm];
          for (i = 0, len = pkgs.length; i < len; i++) {
            pkg = pkgs[i];
            console.log(`linkall: linking up ${pkg.manifest.name}`);
            try {
              await spawn(pm + " link", pkg.path);
            } catch (error) {
              console.warn(`linkall: linking up ${pkg.manifest.name} failed`);
            }
          }
        }
        results1 = [];
        for (j = 0, len1 = pkglist.length; j < len1; j++) {
          pkg = pkglist[j];
          if (((ref = pkg.linkup) != null ? ref.length : void 0) > 0) {
            pm = pkg.pm || options.pm;
            console.log(`linkall: linking local dependencies for ${pkg.manifest.name}`);
            try {
              results1.push((await spawn(pm + " link " + pkg.linkup.join(" "), pkg.path)));
            } catch (error) {
              results1.push(console.warn(`linkall: linking local dependencies for ${pkg.manifest.name} failed`));
            }
          } else {
            results1.push(void 0);
          }
        }
        return results1;
      }
    }).then(async() => {
      var i, len, pkg, pm, results1;
      if (!options.test && !options.noInstall) {
        pm = options.pm;
        results1 = [];
        for (i = 0, len = toInstall.length; i < len; i++) {
          pkg = toInstall[i];
          console.log(`linkall: installing ${pkg.manifest.name} in ${pkg.path}`);
          try {
            results1.push((await spawn(pm + " install", pkg.path)));
          } catch (error) {
            results1.push(console.warn(`linkall: installing ${pkg.manifest.name} in ${pkg.path} failed`));
          }
        }
        return results1;
      }
    }).catch((e) => {
      return console.log(e);
    });
    return (sig) => {
      var child, i, len, results1;
      results1 = [];
      for (i = 0, len = children.length; i < len; i++) {
        child = children[i];
        results1.push(child.close(sig));
      }
      return results1;
    };
  };

}).call(this);
